# Source Code

In this directory we have 

- `__init__.py`: initialization of halophot.

- `halo_tools.py`: main library of functions that implement TV-min photometry.

- `kephalophot.py`: old library, deprecated.
